from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BbCls:
	"""Bb commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bb", core, parent)

	# noinspection PyTypeChecker
	def get(self) -> enums.Path:
		"""SCPI: CONFigure:GENerator:TARGet:PATH:BB \n
		Snippet: value: enums.Path = driver.configure.generator.target.path.bb.get() \n
		Queries the BB signal path of the generator used for signal generation. \n
			:return: path: A | B"""
		response = self._core.io.query_str(f'CONFigure:GENerator:TARGet:PATH:BB?')
		return Conversions.str_to_scalar_enum(response, enums.Path)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FailCls:
	"""Fail commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fail", core, parent)

	def get(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> float:
		"""SCPI: CALCulate<n>:LIMit<li>:FAIL \n
		Snippet: value: float = driver.calculate.limit.fail.get(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command queries the result of a limit check in the specified window. Note that for SEM measurements, the limit line
		suffix 'li' is irrelevant, as only one specific SEM limit line is checked for the currently relevant power class. To get
		a valid result, you have to perform a complete measurement with synchronization to the end of the measurement before
		reading out the result. This is only possible for single sweep mode. See also method RsFsw.Applications.K10x_Lte.Initiate.
		Continuous.set. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:return: result: 0 PASS 1 FAIL"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:FAIL?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AverageCls:
	"""Average commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("average", core, parent)

	def get(self) -> float:
		"""SCPI: FETCh:EVM:DATA:AVERage \n
		Snippet: value: float = driver.applications.k9X11Ad.fetch.evm.data.average.get() \n
		This command returns the average, maximum or minimum EVM for data symbols for the PPDU in dB. For details see 'EVM Data
		Symbols [dB]'. \n
			:return: result: No help available"""
		response = self._core.io.query_str(f'FETCh:EVM:DATA:AVERage?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, once: enums.EventOnce) -> None:
		"""SCPI: [SENSe]:POWer:ACHannel:REFerence:AUTO \n
		Snippet: driver.applications.k14Xnr5G.sense.power.achannel.reference.auto.set(once = enums.EventOnce.ONCE) \n
		No command help available \n
			:param once: No help available
		"""
		param = Conversions.enum_scalar_to_str(once, enums.EventOnce)
		self._core.io.write(f'SENSe:POWer:ACHannel:REFerence:AUTO {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: enums.OffState, window=repcap.Window.Default, marker=repcap.Marker.Default, subBlock=repcap.SubBlock.Default) -> None:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:POWer<sb>[:STATe] \n
		Snippet: driver.calculate.marker.function.power.state.set(state = enums.OffState.OFF, window = repcap.Window.Default, marker = repcap.Marker.Default, subBlock = repcap.SubBlock.Default) \n
		This command turns a power measurement on and off. \n
			:param state: ON | OFF | 1 | 0 ON | 1 The power measurement selected with method RsFsw.Calculate.Marker.Function.Power.Select.set is activated. OFF | 0 A standard frequency sweep is activated.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Power')
		"""
		param = Conversions.enum_scalar_to_str(state, enums.OffState)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		self._core.io.write(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:POWer{subBlock_cmd_val}:STATe {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default, subBlock=repcap.SubBlock.Default) -> enums.OffState:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:POWer<sb>[:STATe] \n
		Snippet: value: enums.OffState = driver.calculate.marker.function.power.state.get(window = repcap.Window.Default, marker = repcap.Marker.Default, subBlock = repcap.SubBlock.Default) \n
		This command turns a power measurement on and off. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Power')
			:return: state: ON | OFF | 1 | 0 ON | 1 The power measurement selected with method RsFsw.Calculate.Marker.Function.Power.Select.set is activated. OFF | 0 A standard frequency sweep is activated."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:POWer{subBlock_cmd_val}:STATe?')
		return Conversions.str_to_scalar_enum(response, enums.OffState)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NoRbCls:
	"""NoRb commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("noRb", core, parent)

	def set(self, resource_blocks: float, carrierComponent=repcap.CarrierComponent.Default) -> None:
		"""SCPI: CONFigure[:LTE]:UL[:CC<cc>]:PUCCh:NORB \n
		Snippet: driver.applications.k10Xlte.configure.lte.uplink.cc.pucch.noRb.set(resource_blocks = 1.0, carrierComponent = repcap.CarrierComponent.Default) \n
		This command selects the number of resource blocks for the PUCCH. \n
			:param resource_blocks: numeric value Selects the number of RBs. AUTO Detects the number of RBs automatically.
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
		"""
		param = Conversions.decimal_value_to_str(resource_blocks)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		self._core.io.write(f'CONFigure:LTE:UL:CC{carrierComponent_cmd_val}:PUCCh:NORB {param}')

	def get(self, carrierComponent=repcap.CarrierComponent.Default) -> float:
		"""SCPI: CONFigure[:LTE]:UL[:CC<cc>]:PUCCh:NORB \n
		Snippet: value: float = driver.applications.k10Xlte.configure.lte.uplink.cc.pucch.noRb.get(carrierComponent = repcap.CarrierComponent.Default) \n
		This command selects the number of resource blocks for the PUCCH. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:return: resource_blocks: numeric value Selects the number of RBs. AUTO Detects the number of RBs automatically."""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		response = self._core.io.query_str(f'CONFigure:LTE:UL:CC{carrierComponent_cmd_val}:PUCCh:NORB?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DtimeCls:
	"""Dtime commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dtime", core, parent)

	@property
	def auto(self):
		"""auto commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_auto'):
			from .Auto import AutoCls
			self._auto = AutoCls(self._core, self._cmd_group)
		return self._auto

	def set(self, time: float) -> None:
		"""SCPI: [SENSe]:SWEep:DTIMe \n
		Snippet: driver.sense.sweep.dtime.set(time = 1.0) \n
		Determines the amount of time used to sample a continuous stream of I/Q data. The stream is displayed as multiple rows in
		the spectrogram or waterfall diagrams (as opposed to the sweep time, which defines the time to capture a single row in
		the diagrams) . Dwell time is never applied for triggered measurements. It is only applied in single sweep mode or when
		the Sequencer is in continuous mode. The query returns the amount of time used to sample I/Q data in the current
		measurement. Tip: the dwell time can also be defined automatically, see [SENSe:]SWEep:DTIMe:AUTO. For more information
		see 'Sweep time and detector'. \n
			:param time: numeric value Range: 30 ms to 3600 s, Unit: s
		"""
		param = Conversions.decimal_value_to_str(time)
		self._core.io.write(f'SENSe:SWEep:DTIMe {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:SWEep:DTIMe \n
		Snippet: value: float = driver.sense.sweep.dtime.get() \n
		Determines the amount of time used to sample a continuous stream of I/Q data. The stream is displayed as multiple rows in
		the spectrogram or waterfall diagrams (as opposed to the sweep time, which defines the time to capture a single row in
		the diagrams) . Dwell time is never applied for triggered measurements. It is only applied in single sweep mode or when
		the Sequencer is in continuous mode. The query returns the amount of time used to sample I/Q data in the current
		measurement. Tip: the dwell time can also be defined automatically, see [SENSe:]SWEep:DTIMe:AUTO. For more information
		see 'Sweep time and detector'. \n
			:return: time: numeric value Range: 30 ms to 3600 s, Unit: s"""
		response = self._core.io.query_str(f'SENSe:SWEep:DTIMe?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'DtimeCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DtimeCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LevelCls:
	"""Level commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("level", core, parent)

	@property
	def all(self):
		"""all commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_all'):
			from .All import AllCls
			self._all = AllCls(self._core, self._cmd_group)
		return self._all

	def set(self) -> None:
		"""SCPI: [SENSe]:ADJust:LEVel \n
		Snippet: driver.applications.k14Xnr5G.sense.adjust.level.set() \n
		This command adjusts the level settings, including attenuator and preamplifier, to achieve the best dynamic range.
		Compared to [SENSe:]ADJust:EVM, which achieves the best amplitude settings to optimize the EVM, you can use this command
		for a quick determination of preliminary amplitude settings. \n
		"""
		self._core.io.write(f'SENSe:ADJust:LEVel')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SENSe]:ADJust:LEVel \n
		Snippet: driver.applications.k14Xnr5G.sense.adjust.level.set_with_opc() \n
		This command adjusts the level settings, including attenuator and preamplifier, to achieve the best dynamic range.
		Compared to [SENSe:]ADJust:EVM, which achieves the best amplitude settings to optimize the EVM, you can use this command
		for a quick determination of preliminary amplitude settings. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:ADJust:LEVel', opc_timeout_ms)

	def clone(self) -> 'LevelCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = LevelCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.RepeatedCapability import RepeatedCapability
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FetchCls:
	"""Fetch commands group definition. 495 total commands, 21 Subgroups, 0 group commands
	Repeated Capability: Window, default value after init: Window.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fetch", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_window_get', 'repcap_window_set', repcap.Window.Nr1)

	def repcap_window_set(self, window: repcap.Window) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Window.Default
		Default value after init: Window.Nr1"""
		self._cmd_group.set_repcap_enum_value(window)

	def repcap_window_get(self) -> repcap.Window:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def mdpd(self):
		"""mdpd commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_mdpd'):
			from .Mdpd import MdpdCls
			self._mdpd = MdpdCls(self._core, self._cmd_group)
		return self._mdpd

	@property
	def power(self):
		"""power commands group. 10 Sub-classes, 0 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def amam(self):
		"""amam commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_amam'):
			from .Amam import AmamCls
			self._amam = AmamCls(self._core, self._cmd_group)
		return self._amam

	@property
	def amPm(self):
		"""amPm commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_amPm'):
			from .AmPm import AmPmCls
			self._amPm = AmPmCls(self._core, self._cmd_group)
		return self._amPm

	@property
	def apae(self):
		"""apae commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_apae'):
			from .Apae import ApaeCls
			self._apae = ApaeCls(self._core, self._cmd_group)
		return self._apae

	@property
	def bbPower(self):
		"""bbPower commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_bbPower'):
			from .BbPower import BbPowerCls
			self._bbPower = BbPowerCls(self._core, self._cmd_group)
		return self._bbPower

	@property
	def dpd(self):
		"""dpd commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_dpd'):
			from .Dpd import DpdCls
			self._dpd = DpdCls(self._core, self._cmd_group)
		return self._dpd

	@property
	def ddpd(self):
		"""ddpd commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_ddpd'):
			from .Ddpd import DdpdCls
			self._ddpd = DdpdCls(self._core, self._cmd_group)
		return self._ddpd

	@property
	def icc(self):
		"""icc commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_icc'):
			from .Icc import IccCls
			self._icc = IccCls(self._core, self._cmd_group)
		return self._icc

	@property
	def ivoltage(self):
		"""ivoltage commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ivoltage'):
			from .Ivoltage import IvoltageCls
			self._ivoltage = IvoltageCls(self._core, self._cmd_group)
		return self._ivoltage

	@property
	def maccuracy(self):
		"""maccuracy commands group. 13 Sub-classes, 0 commands."""
		if not hasattr(self, '_maccuracy'):
			from .Maccuracy import MaccuracyCls
			self._maccuracy = MaccuracyCls(self._core, self._cmd_group)
		return self._maccuracy

	@property
	def pc(self):
		"""pc commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pc'):
			from .Pc import PcCls
			self._pc = PcCls(self._core, self._cmd_group)
		return self._pc

	@property
	def pcpa(self):
		"""pcpa commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pcpa'):
			from .Pcpa import PcpaCls
			self._pcpa = PcpaCls(self._core, self._cmd_group)
		return self._pcpa

	@property
	def pservoing(self):
		"""pservoing commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pservoing'):
			from .Pservoing import PservoingCls
			self._pservoing = PservoingCls(self._core, self._cmd_group)
		return self._pservoing

	@property
	def ptable(self):
		"""ptable commands group. 16 Sub-classes, 0 commands."""
		if not hasattr(self, '_ptable'):
			from .Ptable import PtableCls
			self._ptable = PtableCls(self._core, self._cmd_group)
		return self._ptable

	@property
	def qvoltage(self):
		"""qvoltage commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_qvoltage'):
			from .Qvoltage import QvoltageCls
			self._qvoltage = QvoltageCls(self._core, self._cmd_group)
		return self._qvoltage

	@property
	def sync(self):
		"""sync commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sync'):
			from .Sync import SyncCls
			self._sync = SyncCls(self._core, self._cmd_group)
		return self._sync

	@property
	def ttf(self):
		"""ttf commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ttf'):
			from .Ttf import TtfCls
			self._ttf = TtfCls(self._core, self._cmd_group)
		return self._ttf

	@property
	def tts(self):
		"""tts commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_tts'):
			from .Tts import TtsCls
			self._tts = TtsCls(self._core, self._cmd_group)
		return self._tts

	@property
	def vcc(self):
		"""vcc commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_vcc'):
			from .Vcc import VccCls
			self._vcc = VccCls(self._core, self._cmd_group)
		return self._vcc

	@property
	def stable(self):
		"""stable commands group. 27 Sub-classes, 0 commands."""
		if not hasattr(self, '_stable'):
			from .Stable import StableCls
			self._stable = StableCls(self._core, self._cmd_group)
		return self._stable

	def clone(self) -> 'FetchCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FetchCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SpectrogramCls:
	"""Spectrogram commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("spectrogram", core, parent)

	def set(self, filename: str, store=repcap.Store.Default) -> None:
		"""SCPI: MMEMory:STORe<n>:SPECtrogram \n
		Snippet: driver.massMemory.store.spectrogram.set(filename = '1', store = repcap.Store.Default) \n
		This command exports spectrogram data to an ASCII file. The file contains the data for every frame in the history buffer.
		The data corresponding to a particular frame begins with information about the frame number and the time that frame was
		recorded. Note that, depending on the size of the history buffer, the process of exporting the data can take a while.
		Secure User Mode In secure user mode, settings that are stored on the instrument are stored to volatile memory, which is
		restricted to 256 MB. Thus, a 'memory limit reached' error can occur although the hard disk indicates that storage space
		is still available. To store data permanently, select an external storage location such as a USB memory device.
		For details, see 'Protecting Data Using the Secure User Mode'. \n
			:param filename: String containing the path and name of the target file.
			:param store: optional repeated capability selector. Default value: Pos1 (settable in the interface 'Store')
		"""
		param = Conversions.value_to_quoted_str(filename)
		store_cmd_val = self._cmd_group.get_repcap_cmd_value(store, repcap.Store)
		self._core.io.write(f'MMEMory:STORe{store_cmd_val}:SPECtrogram {param}')

	def get(self, store=repcap.Store.Default) -> str:
		"""SCPI: MMEMory:STORe<n>:SPECtrogram \n
		Snippet: value: str = driver.massMemory.store.spectrogram.get(store = repcap.Store.Default) \n
		This command exports spectrogram data to an ASCII file. The file contains the data for every frame in the history buffer.
		The data corresponding to a particular frame begins with information about the frame number and the time that frame was
		recorded. Note that, depending on the size of the history buffer, the process of exporting the data can take a while.
		Secure User Mode In secure user mode, settings that are stored on the instrument are stored to volatile memory, which is
		restricted to 256 MB. Thus, a 'memory limit reached' error can occur although the hard disk indicates that storage space
		is still available. To store data permanently, select an external storage location such as a USB memory device.
		For details, see 'Protecting Data Using the Secure User Mode'. \n
			:param store: optional repeated capability selector. Default value: Pos1 (settable in the interface 'Store')
			:return: filename: String containing the path and name of the target file."""
		store_cmd_val = self._cmd_group.get_repcap_cmd_value(store, repcap.Store)
		response = self._core.io.query_str(f'MMEMory:STORe{store_cmd_val}:SPECtrogram?')
		return trim_str_response(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BandwidthCls:
	"""Bandwidth commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bandwidth", core, parent)

	def set(self, bandwidth: float) -> None:
		"""SCPI: TRACe:IQ:BWIDth \n
		Snippet: driver.applications.k18AmplifierEt.trace.iq.bandwidth.set(bandwidth = 1.0) \n
		This command defines the analysis bandwidth with which the amplified signal is captured. This command is available when
		method RsFsw.Applications.K18_AmplifierEt.Trace.Iq.SymbolRate.Auto.set has been turned off. Note that when you change the
		analysis bandwidth, the sample rate and capture length are adjusted automatically to the new bandwidth. \n
			:param bandwidth: numeric value Note that the application automatically adjusts the sample rate when you change the bandwidth manually. Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(bandwidth)
		self._core.io.write(f'TRACe:IQ:BWIDth {param}')

	def get(self) -> float:
		"""SCPI: TRACe:IQ:BWIDth \n
		Snippet: value: float = driver.applications.k18AmplifierEt.trace.iq.bandwidth.get() \n
		This command defines the analysis bandwidth with which the amplified signal is captured. This command is available when
		method RsFsw.Applications.K18_AmplifierEt.Trace.Iq.SymbolRate.Auto.set has been turned off. Note that when you change the
		analysis bandwidth, the sample rate and capture length are adjusted automatically to the new bandwidth. \n
			:return: bandwidth: numeric value Note that the application automatically adjusts the sample rate when you change the bandwidth manually. Unit: Hz"""
		response = self._core.io.query_str(f'TRACe:IQ:BWIDth?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RatioCls:
	"""Ratio commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ratio", core, parent)

	def set(self, ratio: float) -> None:
		"""SCPI: [SENSe]:BWIDth[:RESolution]:RATio \n
		Snippet: driver.applications.k14Xnr5G.sense.bandwidth.resolution.ratio.set(ratio = 1.0) \n
		No command help available \n
			:param ratio: No help available
		"""
		param = Conversions.decimal_value_to_str(ratio)
		self._core.io.write(f'SENSe:BWIDth:RESolution:RATio {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:BWIDth[:RESolution]:RATio \n
		Snippet: value: float = driver.applications.k14Xnr5G.sense.bandwidth.resolution.ratio.get() \n
		No command help available \n
			:return: ratio: No help available"""
		response = self._core.io.query_str(f'SENSe:BWIDth:RESolution:RATio?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelectCls:
	"""Select commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("select", core, parent)

	def set(self, file_path: str, inputIx=repcap.InputIx.Default, fileList=repcap.FileList.Default) -> None:
		"""SCPI: [SENSe]:CORRection:FRESponse:INPut<ip>:USER:FLISt<fli>:SELect \n
		Snippet: driver.sense.correction.fresponse.inputPy.user.flist.select.set(file_path = '1', inputIx = repcap.InputIx.Default, fileList = repcap.FileList.Default) \n
		Loads an additional frequency response (.fres) file to the current configuration. \n
			:param file_path: string Path and file name The default directory for .fres files is C:/R_S/INSTR/USER/Fresponse.
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:param fileList: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Flist')
		"""
		param = Conversions.value_to_quoted_str(file_path)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		fileList_cmd_val = self._cmd_group.get_repcap_cmd_value(fileList, repcap.FileList)
		self._core.io.write(f'SENSe:CORRection:FRESponse:INPut{inputIx_cmd_val}:USER:FLISt{fileList_cmd_val}:SELect {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PowerCls:
	"""Power commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("power", core, parent)

	def set(self, xaxis: enums.PulsePowerItems, yaxis: enums.YaXisItems, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:DISTribution:POWer \n
		Snippet: driver.applications.k6Pulse.calculate.distribution.power.set(xaxis = enums.PulsePowerItems.ADDB, yaxis = enums.YaXisItems.COUNt, window = repcap.Window.Default) \n
		Configures the Parameter Distribution result display. \n
			:param xaxis: TOP | BASE | AMPLitude | ON | AVG | MIN | MAX | PON | PAVG | PMIN | ADPercent | ADDB | RPERcent | RDB | OPERcent | ODB | POINt | PPRatio | I | Q Pulse parameter to be displayed on the x-axis. For a description of the available parameters see 'Phase parameters'. TOP Top Power BASE Base Power AMPLitude Pulse Amplitude ON Average ON Power AVG Average Tx Power MIN Minimum Power MAX Peak Power PON Peak-to-Avg ON Power Ratio PAVG Peak-to-Average Tx Power Ratio PMIN Peak-to-Min Power Ratio ADPercent Droop in % ADDB Droop in dB RPERcent Ripple in % RDB Ripple in dB OPERcent Overshoot in % ODB Overshoot in dB POINt Pulse power measured at measurement point PPRatio Pulse-to-Pulse Power Difference
			:param yaxis: COUNt | OCCurrence Parameter to be displayed on the y-axis. COUNt Number of pulses in which the parameter value occurred. OCCurrence Percentage of all measured pulses in which the parameter value occurred.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('xaxis', xaxis, DataType.Enum, enums.PulsePowerItems), ArgSingle('yaxis', yaxis, DataType.Enum, enums.YaXisItems))
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:DISTribution:POWer {param}'.rstrip())



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FilterPyCls:
	"""FilterPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("filterPy", core, parent)

	def set(self, filter_py: enums.FilterDemodNr5G) -> None:
		"""SCPI: [SENSe]:NR5G:DEMod:FILTer \n
		Snippet: driver.applications.k14Xnr5G.sense.nr5G.demod.filterPy.set(filter_py = enums.FilterDemodNr5G.MFILter) \n
		This command selects the filter for suppression of neighboring channels. \n
			:param filter_py: MFILter Multicarrier filter. NONE No filter. PBWP Bandwidthpart filter.
		"""
		param = Conversions.enum_scalar_to_str(filter_py, enums.FilterDemodNr5G)
		self._core.io.write(f'SENSe:NR5G:DEMod:FILTer {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.FilterDemodNr5G:
		"""SCPI: [SENSe]:NR5G:DEMod:FILTer \n
		Snippet: value: enums.FilterDemodNr5G = driver.applications.k14Xnr5G.sense.nr5G.demod.filterPy.get() \n
		This command selects the filter for suppression of neighboring channels. \n
			:return: filter_py: MFILter Multicarrier filter. NONE No filter. PBWP Bandwidthpart filter."""
		response = self._core.io.query_str(f'SENSe:NR5G:DEMod:FILTer?')
		return Conversions.str_to_scalar_enum(response, enums.FilterDemodNr5G)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DpdCls:
	"""Dpd commands group definition. 18 total commands, 11 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dpd", core, parent)

	@property
	def amam(self):
		"""amam commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_amam'):
			from .Amam import AmamCls
			self._amam = AmamCls(self._core, self._cmd_group)
		return self._amam

	@property
	def amxm(self):
		"""amxm commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_amxm'):
			from .Amxm import AmxmCls
			self._amxm = AmxmCls(self._core, self._cmd_group)
		return self._amxm

	@property
	def amPm(self):
		"""amPm commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_amPm'):
			from .AmPm import AmPmCls
			self._amPm = AmPmCls(self._core, self._cmd_group)
		return self._amPm

	@property
	def fname(self):
		"""fname commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fname'):
			from .Fname import FnameCls
			self._fname = FnameCls(self._core, self._cmd_group)
		return self._fname

	@property
	def file(self):
		"""file commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_file'):
			from .File import FileCls
			self._file = FileCls(self._core, self._cmd_group)
		return self._file

	@property
	def method(self):
		"""method commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_method'):
			from .Method import MethodCls
			self._method = MethodCls(self._core, self._cmd_group)
		return self._method

	@property
	def morder(self):
		"""morder commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_morder'):
			from .Morder import MorderCls
			self._morder = MorderCls(self._core, self._cmd_group)
		return self._morder

	@property
	def sequence(self):
		"""sequence commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sequence'):
			from .Sequence import SequenceCls
			self._sequence = SequenceCls(self._core, self._cmd_group)
		return self._sequence

	@property
	def shaping(self):
		"""shaping commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_shaping'):
			from .Shaping import ShapingCls
			self._shaping = ShapingCls(self._core, self._cmd_group)
		return self._shaping

	@property
	def tradeoff(self):
		"""tradeoff commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tradeoff'):
			from .Tradeoff import TradeoffCls
			self._tradeoff = TradeoffCls(self._core, self._cmd_group)
		return self._tradeoff

	@property
	def update(self):
		"""update commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_update'):
			from .Update import UpdateCls
			self._update = UpdateCls(self._core, self._cmd_group)
		return self._update

	def clone(self) -> 'DpdCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DpdCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group
